from typing import Literal

TextDecoration = Literal[
    'underline',
    'overline',
    'line-through',
    'no-underline',
]
